<?php

namespace Gw\Gwcatalog\Domain\Service;

use Gw\Gwcatalog\Domain\Model\Category;
use Gw\Gwcatalog\Domain\Model\Product;
use TYPO3\CMS\Extbase\Persistence\ObjectStorage;

class ImportService
{
    /**
     * @var \Gw\Gwcatalog\Domain\Repository\ProductRepository
     * @TYPO3\CMS\Extbase\Annotation\Inject
     */
    protected $productRepository = null;

    /**
     * @var \Gw\Gwcatalog\Domain\Repository\CategoryRepository
     * @TYPO3\CMS\Extbase\Annotation\Inject
     */
    protected $categoryRepository = null;

    /**
     * @var \Gw\Gwcatalog\Domain\Service\TranslationService
     * @TYPO3\CMS\Extbase\Annotation\Inject
     */
    protected $translateService = null;

    public function ensureTestData(): void
    {
        $category = new Category();
        $this->categoryRepository->add($category);
        $this->categoryRepository->persistAll();
        $product = new Product();
        $this->productRepository->add($product);
        $this->productRepository->persistAll();
        $this->translateService->translate($product, 1);
        $this->translateService->translate($category, 1);
    }

    public function translateIteration(): void
    {
        $category = $this->categoryRepository->findByUid(1);
        $product = $this->productRepository->findByUid(1);
        /** @var Product $translatedProduct */
        $translatedProduct = $this->translateService->translate($product, 1);
        /** @var Category $translatedCategory */
        $translatedCategory = $this->translateService->translate($category, 1);
        $categoryList = new ObjectStorage();
        $categoryList->attach($translatedCategory);
        $translatedProduct->setCategoryList($categoryList); // This doesn't work the second time the method gets executed
//        $translatedProduct->setCategoryList(new ObjectStorage()); // Doesn't work too to just reset the relation
        $this->productRepository->update($translatedProduct);
        $this->productRepository->persistAll();
    }
}
