<?php

namespace Gw\Gwcatalog\Domain\Service;

use Gw\Gwcatalog\Domain\Model\AbstractEntity;
use Gw\Gwcatalog\Domain\Repository\AbstractRepository;
use TYPO3\CMS\Core\Utility\ClassNamingUtility;

/**
 * Class TranslationService
 * @package Gw\Gwproductcatalogimport\Domain\Service
 * Diese Klasse ist für die Entitätenübersetzungen verantwortlich.
 */
class TranslationService
{
    /**
     * @var \TYPO3\CMS\Extbase\Persistence\Generic\Mapper\DataMapper
     * @TYPO3\CMS\Extbase\Annotation\Inject
     */
    protected $dataMapper;

    /**
     * @var \TYPO3\CMS\Core\DataHandling\DataHandler
     * @TYPO3\CMS\Extbase\Annotation\Inject
     */
    protected $dataHandler;

    /**
     * @var \TYPO3\CMS\Extbase\Object\ObjectManager
     * @TYPO3\CMS\Extbase\Annotation\Inject
     */
    protected $objectManager;

    /**
     * Diese Methode liefert eine Übersetzung einer Entität zurück oder legt eine an und liefert diese zurück.
     * @param AbstractEntity $entity
     * @param int $targetLanguageUid
     * @return AbstractEntity
     */
    public function translate(AbstractEntity $entity, int $targetLanguageUid): AbstractEntity
    {
        /** @var AbstractRepository $repository */
        $repository = $this->objectManager->get(ClassNamingUtility::translateModelNameToRepositoryName(get_class($entity)));
        /** @var AbstractEntity $translatedEntity */
        $translatedEntity = $repository->findTranslationByUid($entity->getUid(), $targetLanguageUid);
        if (empty($translatedEntity)) {
            $table = $this->dataMapper->convertClassNameToTableName(get_class($entity));
            $this->dataHandler->start([], [
                $table => [
                    $entity->getUid() => ['localize' => $targetLanguageUid]
                ]
            ], null);
            $this->dataHandler->process_cmdmap();
            $translatedEntity = $repository->findTranslationByUid($entity->getUid(), $targetLanguageUid);
        }
        return $translatedEntity;
    }
}
